pub struct ZlibString(pub String);Tuple Fields
0: StringTrait Implementations
Sourceimpl ByteStreamIo for ZlibString
Compresses a string to zlib then writes it to the writer.
impl ByteStreamIo for ZlibString
Compresses a string to zlib then writes it to the writer.
Sourceimpl Clone for ZlibString
impl Clone for ZlibString
Sourcefn clone(&self) -> ZlibString
fn clone(&self) -> ZlibString
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZlibString
impl Debug for ZlibString
Sourceimpl Default for ZlibString
impl Default for ZlibString
Sourcefn default() -> ZlibString
fn default() -> ZlibString
Returns the “default value” for a type. Read more
Sourceimpl Display for ZlibString
impl Display for ZlibString
Sourceimpl From<String> for ZlibString
impl From<String> for ZlibString
Sourcefn from(original: String) -> ZlibString
fn from(original: String) -> ZlibString
Converts to this type from the input type.
Sourceimpl From<ZlibString> for String
impl From<ZlibString> for String
Sourcefn from(original: ZlibString) -> Self
fn from(original: ZlibString) -> Self
Converts to this type from the input type.
Sourceimpl Ord for ZlibString
impl Ord for ZlibString
Sourcefn cmp(&self, other: &ZlibString) -> Ordering
fn cmp(&self, other: &ZlibString) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ZlibString
impl PartialEq for ZlibString
Sourcefn eq(&self, other: &ZlibString) -> bool
fn eq(&self, other: &ZlibString) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ZlibString
impl PartialOrd for ZlibString
impl Eq for ZlibString
impl StructuralPartialEq for ZlibString